//! A module to import many generated files plus some custom tests
//!
//! For most generated files, the 'test' is just making sure it compiles!

pub mod basic;
pub mod issue118;
pub mod issue118_2;
pub mod issue_170;
pub mod issue_170_a;
pub mod issue_170_b;
pub mod issue_170_c;
pub mod issue_170_common;
pub mod issue_170_d;
pub mod issue_170_e;
pub mod nonunique_1;
pub mod nonunique_2;
pub mod shared0;
pub mod special;
pub mod struct_pb;
pub mod test_basic;
pub mod test_default_values;
pub mod test_default_values_test;
pub mod test_deprecated_lifetime;
pub mod test_deprecated_lifetime_can_compile;
pub mod test_enum_values_pb;
pub mod test_ident_pb;
pub mod test_import_nested_imported_pb;
pub mod test_import_nested_pb;
pub mod test_import_nonunique_pb;
pub mod test_import_root_imported_pb;
pub mod test_import_root_pb;
pub mod test_lite_runtime;
pub mod test_lite_runtime_test;
pub mod test_name_resolution;
pub mod test_name_resolution_p2;
pub mod test_name_resolution_p3;
pub mod test_name_resolution_p4;
pub mod test_nested_package_dir;
pub mod test_nested_package_dir_alt;
pub mod test_nonunique_enum_pb;
pub mod test_oneof;
pub mod test_oneof_pb;
pub mod test_owned;
pub mod test_owned_pb;
pub mod test_required;
pub mod test_required_test;
pub mod test_sanitize_file_name_pb;
pub mod test_sync;
pub mod test_text_format;
pub mod test_text_format_pb;
